# python related
*.egg-info
*.pyc
*.pyo

# translation related
*.mo

# tools related
build/
.coverage
.*project
coverage.xml
dist/
docs/_build
__pycache__/
.tox
.vscode/
node_modules/
forest.dot
forest.json

# venv / buildout related
bin/
develop-eggs/
eggs/
.eggs/
etc/
.installed.cfg
include/
lib/
lib64
.mr.developer.cfg
parts/
pyvenv.cfg
var/
local.cfg

# mxdev
/instance/
/.make-sentinels/
/*-mxdev.txt
/reports/
/sources/
/venv/
.installed.txt

%(extra_lines)s
##
# Add extra configuration options in .meta.toml:
#  [gitignore]
#  extra_lines = """
#  _your own configuration lines_
#  """
##
