ci:
    autofix_prs: false
    autoupdate_schedule: monthly

repos:
-   repo: https://github.com/asottile/pyupgrade
    rev: v3.21.0
    hooks:
    -   id: pyupgrade
        args: [--py38-plus]
-   repo: https://github.com/pycqa/isort
    rev: 7.0.0
    hooks:
    -   id: isort
-   repo: https://github.com/psf/black-pre-commit-mirror
    rev: 25.9.0
    hooks:
    -   id: black
-   repo: https://github.com/collective/zpretty
    rev: 3.1.1
    hooks:
    -   id: zpretty
%(zpretty_extra_lines)s
##
# Add extra configuration options in .meta.toml:
#  [pre_commit]
#  zpretty_extra_lines = """
#  _your own configuration lines_
#  """
##
-   repo: https://github.com/PyCQA/flake8
    rev: 7.3.0
    hooks:
    -   id: flake8
%(flake8_extra_lines)s
##
# Add extra configuration options in .meta.toml:
#  [pre_commit]
#  flake8_extra_lines = """
#  _your own configuration lines_
#  """
##
-   repo: https://github.com/codespell-project/codespell
    rev: v2.4.1
    hooks:
    -   id: codespell
        additional_dependencies:
          - tomli
%(codespell_extra_lines)s
##
# Add extra configuration options in .meta.toml:
#  [pre_commit]
#  codespell_extra_lines = """
#  _your own configuration lines_
#  """
##
-   repo: https://github.com/mgedmin/check-manifest
    rev: "0.51"
    hooks:
    -   id: check-manifest
-   repo: https://github.com/regebro/pyroma
    rev: "5.0"
    hooks:
    -   id: pyroma
-   repo: https://github.com/mgedmin/check-python-versions
    rev: "0.23.0"
    hooks:
    -   id: check-python-versions
        args: ['--only', 'setup.py,pyproject.toml']
-   repo: https://github.com/collective/i18ndude
    rev: "6.2.1"
    hooks:
    -   id: i18ndude
%(i18ndude_extra_lines)s

##
# Add extra configuration options in .meta.toml:
#  [pre_commit]
#  i18ndude_extra_lines = """
#  _your own configuration lines_
#  """
##

%(extra_lines)s
##
# Add extra configuration options in .meta.toml:
#  [pre_commit]
#  extra_lines = """
#  _your own configuration lines_
#  """
##
